@@ -22,9 +22,9 @@ from ..utils.family_ops import restructure_list_to_exclude_certain_family_member
 from ..event_handler.event_type import EventType
 from ..event_handler import EVENT_DISPATCHER
 from ..logger import log
-from ..window import Window
 from pyglet.window import key
 
+
 class Scene(object):
     CONFIG = {
         "window_config": {},
@@ -107,7 +107,7 @@ class Scene(object):
         # which updates the frame while under
         # the hood calling the pyglet event loop
         log.info("Tips: You are now in the interactive mode. Now you can use the keyboard"
-            " and the mouse to interact with the scene. Just press `q` if you want to quit.")
+                 " and the mouse to interact with the scene. Just press `q` if you want to quit.")
         self.quit_interaction = False
         self.lock_static_mobject_data()
         while not (self.window.is_closing or self.quit_interaction):
@@ -140,7 +140,7 @@ class Scene(object):
         for term in ("play", "wait", "add", "remove", "clear", "save_state", "restore"):
             local_ns[term] = getattr(self, term)
         log.info("Tips: Now the embed iPython terminal is open. But you can't interact with"
-            " the window directly. To do so, you need to type `touch()` or `self.interact()`")
+                 " the window directly. To do so, you need to type `touch()` or `self.interact()`")
         shell(local_ns=local_ns, stack_depth=2)
         # End scene when exiting an embed.
         raise EndSceneEarlyException()
@@ -289,19 +289,24 @@ class Scene(object):
             self.skip_time += self.time
 
     # Methods associated with running animations
-    def get_time_progression(self, run_time, n_iterations=None, override_skip_animations=False):
+    def get_time_progression(self, run_time, n_iterations=None, desc="", override_skip_animations=False):
         if self.skip_animations and not override_skip_animations:
-            times = [run_time]
+            return [run_time]
         else:
             step = 1 / self.camera.frame_rate
             times = np.arange(0, run_time, step)
-        time_progression = ProgressDisplay(
+
+        if self.file_writer.has_progress_display:
+            self.file_writer.set_progress_display_subdescription(desc)
+            return times
+
+        return ProgressDisplay(
             times,
             total=n_iterations,
             leave=self.leave_progress_bars,
-            ascii=True if platform.system() == 'Windows' else None
+            ascii=True if platform.system() == 'Windows' else None,
+            desc=desc,
         )
-        return time_progression
 
     def get_run_time(self, animations):
         runtime_list = [animation.run_time for animation in animations]
@@ -310,30 +315,18 @@ class Scene(object):
 
     def get_animation_time_progression(self, animations):
         run_time = self.get_run_time(animations)
-        time_progression = self.get_time_progression(run_time)
-        description = "".join([
-            f"Animation {self.num_plays}: {animations[0]}",
-            ", etc." if len(animations) > 1 else "",
-        ])
-        time_progression.set_description(description)
+        description = f"{self.num_plays} {animations[0]}"
+        if len(animations) > 1:
+            description += ", etc."
+        time_progression = self.get_time_progression(run_time, desc=description)
         return time_progression
 
-    def get_wait_time_progression(self, duration, stop_condition):
+    def get_wait_time_progression(self, duration, stop_condition=None):
+        kw = {"desc": f"{self.num_plays} Waiting"}
         if stop_condition is not None:
-            time_progression = self.get_time_progression(
-                duration,
-                n_iterations=-1,  # So it doesn't show % progress
-                override_skip_animations=True
-            )
-            time_progression.set_description(
-                "Waiting for {}".format(stop_condition.__name__)
-            )
-        else:
-            time_progression = self.get_time_progression(duration)
-            time_progression.set_description(
-                "Waiting {}".format(self.num_plays)
-            )
-        return time_progression
+            kw["n_iterations"] = -1  # So it doesn't show % progress
+            kw["override_skip_animations"] = True
+        return self.get_time_progression(duration, **kw)
 
     def anims_from_play_args(self, *args, **kwargs):
         """
@@ -517,13 +510,9 @@ class Scene(object):
                     time_progression.close()
                     break
             self.unlock_mobject_data()
-        elif self.skip_animations:
-            # Do nothing
-            return self
         else:
             self.update_frame(duration)
-            n_frames = int(duration * self.camera.frame_rate)
-            for n in range(n_frames):
+            for n in self.get_wait_time_progression(duration):
                 self.emit_frame()
         return self
 
@@ -594,6 +583,17 @@ class Scene(object):
         propagate_event = EVENT_DISPATCHER.dispatch(EventType.MouseDragEvent, **event_data)
         if propagate_event is not None and propagate_event is False:
             return
+        frame = self.camera.frame
+        if buttons == 1:
+            frame.increment_theta(-d_point[0] * 1.5)
+            frame.increment_phi(d_point[1] * 1.5)
+        elif buttons == 4:
+            shift = -d_point
+            shift[0] *= frame.get_width() / 2
+            shift[1] *= frame.get_height() / 2
+            transform = frame.get_inverse_camera_rotation_matrix()
+            shift = np.dot(np.transpose(transform), shift)
+            frame.shift(shift)
 
     def on_mouse_press(self, point, button, mods):
         event_data = {"point": point, "button": button, "mods": mods}
@@ -614,13 +614,13 @@ class Scene(object):
             return
 
         frame = self.camera.frame
-        if self.window.is_key_pressed(ord("z")):
+        if self.window.is_key_pressed(key.Z) or self.window.is_key_pressed(key.LCTRL):
             factor = 1 + np.arctan(27 * offset[1])
             frame.scale(1 / factor, about_point=point)
         else:
             transform = frame.get_inverse_camera_rotation_matrix()
             shift = np.dot(np.transpose(transform), offset)
-            frame.shift(-20.0 * shift)
+            frame.shift(-100.0 * shift)
 
     def on_key_release(self, symbol, modifiers):
         event_data = {"symbol": symbol, "modifiers": modifiers}
@@ -649,7 +649,7 @@ class Scene(object):
         elif symbol in (key.Q, key.TAB):  # key.APOSTROPHE,
             self.quit_interaction = True
 
-        elif symbol in (key.SPACE, key.RCTRL, key.LCTRL):
+        elif symbol in (key.SPACE, key.LALT, key.RALT):
             self.pause = self.pause ^ 1
             time_pause_start = time.time()
             if self.pause:
